Summary: The libglade library for loading user interfaces
Name: libglade2
Version: 2.6.4
Release: 2
License: LGPLv2+
Group: System Environment/Libraries
Source0: http://download.gnome.org/sources/libglade/2.6/libglade-%{version}.tar.bz2
Source1: http://download.gnome.org/sources/libglade/2.6/libglade-%{version}.sha256sum
# http://bugzilla.gnome.org/show_bug.cgi?id=121025
Patch1: libglade-2.0.1-nowarning.patch
# http://bugzilla.gnome.org/show_bug.cgi?id=510736
Patch2: libglade-secondary.patch
URL: http://www.gnome.org
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

Requires: xml-common

BuildRequires: make

BuildRequires: atk-devel >= 1.26
BuildRequires: gettext
BuildRequires: gtk2-devel >= 2.18.5
BuildRequires: glib2-devel >= 2.22.4
BuildRequires: libxml2-devel >= 2.6.32-2
BuildRequires: pango-devel >= 1.24.5

Requires: atk >= 1.26
Requires: gettext
Requires: gtk2 >= 2.18.5
Requires: glib2 >= 2.22.4
Requires: libxml2 >= 2.6.32-2
Requires: pango >= 1.24.5

%define _libdir64 %{_prefix}/lib64

%description
Libglade is a small library that allows a program to load its user
interface from am XML description at runtime. Libglade uses the XML
file format used by the GLADE user interface builder GLADE, so
libglade acts as an alternative to GLADE's code generation
approach. Libglade also provides a simple interface for connecting
handlers to the various signals in the interface (on platforms where
the gmodule library works correctly, it is possible to connect all the
handlers with a single function call). Once the interface has been
instantiated, libglade gives no overhead, so other than the short
initial interface loading time, there is no performance tradeoff.

The library is available as 32-bit and 64-bit.


%package devel
Summary: The files needed for libglade application development
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Requires: atk-devel >= 1.26
Requires: gettext
Requires: gtk2-devel >= 2.18.5
Requires: glib2-devel >= 2.22.4
Requires: libxml2-devel >= 2.6.32-2
Requires: pango-devel >= 1.24.5

%description devel
The libglade-devel package contains the libraries and include files
that you can use to develop libglade applications.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%prep
%setup -q -n libglade-%{version}
export PATH=/opt/freeware/bin:$PATH
%patch1 -p1 -b .nowarning
%patch2 -p1 -b .secondary
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cp -r 32bit/* 64bit/


%build
export CC="xlc_r"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --enable-shared --disable-static \
    --disable-gtk-doc

gmake %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
./configure \
    --prefix=%{_prefix} \
    --enable-shared --disable-static \
    --disable-gtk-doc

gmake %{?_smp_mflags}


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

for f in ${RPM_BUILD_ROOT}%{_bindir}/* ; do
    mv ${f} ${f}_64
done

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

mkdir -p $RPM_BUILD_ROOT%{_libdir}/libglade/2.0
mkdir -p $RPM_BUILD_ROOT%{_libdir64}/libglade/2.0

(
  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done
)

# add the 64-bit shared objects to the shared library containing already the
# 32-bit shared objects
export AR="ar -X32_64"
${AR} -q ${RPM_BUILD_ROOT}%{_libdir}/libglade-2.0.a ${RPM_BUILD_ROOT}%{_libdir64}/libglade-2.0.so.0

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/AUTHORS 32bit/NEWS 32bit/README 32bit/COPYING
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
%dir %{_libdir}/libglade
%dir %{_libdir64}/libglade
%dir %{_libdir}/libglade/2.0
%dir %{_libdir64}/libglade/2.0
%{_datadir}/xml/libglade
/usr/lib/*.a
/usr/lib64/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%defattr(-,root,system,-)
%doc 32bit/test-libglade.c
%{_bindir}/*
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*
%{_libdir64}/pkgconfig/*
%{_datadir}/gtk-doc/html/libglade
/usr/bin/*
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%changelog
* Mon Jul 30 2012 Michael Perzl <michael@perzl.org> - 2.6.4-2
- removed dependency on gettext >= 0.17

* Wed Nov 10 2010 Michael Perzl <michael@perzl.org> - 2.6.4-1
- first version for AIX V5.1 and higher
